Stan Math Library: stan/math/prim/mat/fun/diag_post_multiply.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
diag_post_multiply.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <boost/math/tools/promotion.hpp>`
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 , int R1, int C1, int R2, int C2>
Eigen::Matrix< typename boost::math::tools::promote_args< T1, T2 >::type, R1, C1 > | stan::math::diag_post_multiply (const Eigen::Matrix< T1, R1, C1 > &m1, const Eigen::Matrix< T2, R2, C2 > &m2)

[ Stan Home Page ] © 2011–2016, Stan Development Team.